@@ -1,10 +1,12 @@
+"""Test conf file."""
+
 # -- Project information -----------------------------------------------------
 
 project = "PyData Tests"
 copyright = "2020, Pydata community"
 author = "Pydata community"
 
-master_doc = "index"
+root_doc = "index"
 
 # -- General configuration ---------------------------------------------------
 
